@@ -39,3 +39,6 @@
 
 /* Define if you have /dev/urandom */
 #undef HAVE_DEV_URANDOM
+
+/* Define if you have the libmcrypt library installed */
+#undef HAVE_LIBMCRYPT
