@@ -12,6 +12,7 @@
 #include <time.h>
 #endif
 #include "cipher_sub.h"
+#include "parse.h"
 #include "dact.h"
 #include "ui.h"
 
@@ -41,20 +42,26 @@ int cipher_sub_init(const int mode, char *key) {
 
 int cipher_sub_init_getkey(const int mode, char *key) {
 	char *fname;
-	int fd;
+	char keybuf[1024], *ptrbuf;
+	int fd,x=257;
 
 	fname=dact_ui_getuserinput("Key file: ",128,0);
 	if (mode==DACT_MODE_CDEC) {
 		fd=open(fname, O_RDONLY);
-		read(fd, key, 257);
+		read(fd, &keybuf, sizeof(keybuf));
+		memcpy(key,ptrbuf=demime64(keybuf),257);
 		close(fd);
+		free(ptrbuf);
 		return(257);
 	}
 	if (mode==DACT_MODE_CENC) {
 		fd=open(fname, O_WRONLY|O_CREAT|O_TRUNC, 0600);
 		memcpy(key,generatekey(),257);
-		write(fd, key, 257);
+		memcpy(keybuf, ptrbuf=mimes64(key,&x), 400);
+		write(fd, keybuf, x);
+		write(fd, "\n", 1);
 		close(fd);
+		free(ptrbuf);
 		return(257);
 	}
 	return(-1);
@@ -120,6 +127,7 @@ char *generatekey(void) {
 	int fd;
 	fd=open(RANDOM_DEV, O_RDONLY);
 	read(fd, buff, 1);
+	if (buff[0]==0) buff[0]=3;
 	key[0]=buff[0];
 #else
 	srand(time(NULL)+rand());
@@ -132,7 +140,7 @@ char *generatekey(void) {
 		x=buff[0];
 #else
 		srand(time(NULL)+rand());
-		x=1+(int) (255.0*rand()/(RAND_MAX+1.0));
+		x=(int) (256.0*rand()/(RAND_MAX+1.0));
 #endif
 		if (used[x]==0) { key[i]=x; used[x]=1; } else { i--; }
 	}
