@@ -1,4 +1,5 @@
-
+#ifndef _COMP_SNIBBLE_H
+#define _COMP_SNIBBLE_H
 #include "dact.h"
 #include "config.h"
 
@@ -9,3 +10,4 @@ int comp_snibble_algo(int mode, unsigned char *prev_block, unsigned char *curr_b
 int comp_snibble_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 int comp_snibble_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
 #endif
+#endif
