@@ -27,7 +27,6 @@
 
 
 #include "dact.h"
-#ifdef USE_ZLIB
 #include "comp_zlib.h"
 #include <stdio.h>
 #include <unistd.h>
@@ -68,14 +67,14 @@ int comp_zlib_compress(unsigned char *prev_block, unsigned char *curr_block, cha
 	unsigned long dest_size;
 	int retval;
 	dest_size=(int) ((float) (blk_size*1.01)+13);
+
 #ifdef HAVE_COMPRESS2
 	retval=compress2(out_block, &dest_size, curr_block, blk_size, Z_BEST_COMPRESSION);
 #else
 	retval=compress(out_block, &dest_size, curr_block, blk_size);
 #endif
 	if (retval!=Z_OK) {
-		printf("zlib compression failed.\n");
-		return(blk_size*2);
+		return(-1);
 	}
 	return(dest_size);
 }
@@ -89,9 +88,7 @@ int comp_zlib_decompress(unsigned char *prev_block, unsigned char *curr_block, c
 
 
 	if (retval!=Z_OK) {
-		printf("zlib decompression failed.\n");
 		return(0);
 	}
 	return(dest_size);
 }
-#endif
