@@ -40,7 +40,7 @@ int main(int argc, char **argv);
 
 extern char *optarg;
 extern int optind, opterr, optopt;
-uint32_t DACT_BLK_SIZE=4088;
+uint32_t DACT_BLK_SIZE=0;
 
 int print_help(int argc, char **argv) {
 	printf("DACT %i.%i.%i-%s by Netfuel Design. <dact@rkeene.org>\n", DACT_VER_MAJOR, DACT_VER_MINOR, DACT_VER_REVISION, DACT_VER_SUB);
@@ -76,6 +76,14 @@ int print_help(int argc, char **argv) {
 	return(0);
 }
 
+int dact_blksize_calc(int fsize) {
+	if (fsize==0) return(DACT_BLK_SIZE_DEF);
+	if (fsize<(204800)) {
+		return(fsize);
+	}
+	return(((int) ((((float) fsize)/102400.0)-(0.9999999)))*65535);
+}
+
 void dact_loadconfig(const char *path, char *options) {
 	char *line=NULL, *line_s, *item_buf[4]={NULL, NULL, NULL, NULL};
 	int i;
@@ -455,6 +463,12 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 	fstat(src,&filestats);
 
 	if (mode==DACT_MODE_COMPR) {
+/*
+ * Calculate the default block size.
+ */
+		if (DACT_BLK_SIZE==0) {
+			DACT_BLK_SIZE=dact_blksize_calc(filestats.st_size);
+		}
 		if (((in_buf=malloc(DACT_BLK_SIZE))==NULL) || \
 			((out_buf=malloc(DACT_BLK_SIZE*2))==NULL)) {
 				PERROR("malloc");
@@ -1137,7 +1151,6 @@ int main(int argc, char **argv) {
 		PRINTERR("**-");
 	}
 
-
 	if (mode==DACT_MODE_RET) return(0);
 
 	in_files=&argv[optind];
