@@ -13,7 +13,7 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 1
+#define DACT_VER_REVISION 2
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -27,6 +27,8 @@
 #define DACT_MODE_CINIT	5
 #define DACT_MODE_CENC	6
 #define DACT_MODE_CDEC	7
+#define DACT_MODE_CIENC 11   /* CINIT+CENC */
+#define DACT_MODE_DIDEC 12   /* CINIT+CDEC */
 
 #define DACT_OPT_FORCE	0
 #define DACT_OPT_STDOUT	1
@@ -60,8 +62,13 @@
 #define DACT_HDR_NOP	10
 #define DACT_HDR_IDXDATA	11
 
+#ifndef DACT_BLK_SIZE_MAX
 #define DACT_BLK_SIZE_MAX 4294967296
 #define MAX_DACT_BLK_SIZE DACT_BLK_SIZE_MAX
+#endif
+#ifndef DACT_BLK_SIZE_DEF
+#define DACT_BLK_SIZE_DEF 8192
+#endif
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
