@@ -7,6 +7,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 #include <stdio.h>
 #include "dact.h"
 #include "ui.h"
@@ -49,7 +50,7 @@ void dact_ui_update(void) {
 		fprintf(stderr, "=> [%s%s] %03i%%",bar1,bar2,percent);
 	}
 	fprintf(stderr, " [%c] | Status: %s\033[K\r",*("-\\|/"+(drawing&3)),dact_ui_statusvar);
-	fflush(stdout);
+	fflush(stderr);
 
 	free(bar2);
 	if (bar1!=(bar2+width)) free(bar1);
@@ -133,9 +134,25 @@ void dact_ui_setup(uint32_t blocks) {
 	dact_ui_incrblkcnt(0);
 }
 
+char *dact_ui_getuserinput(char *prompt, unsigned int n, int password) {
+	char *ret;
+
+	if (password) {
+		if (n<128) return(NULL);
+		ret=getpass(prompt);
+		return(ret);
+	} else {
+		if ((ret=malloc(n+1))==NULL) return(NULL);
+		fprintf(stderr, "%s", prompt);
+		fflush(stderr);
+		fgets(ret, n, stdin);
+		ret=strsep(&ret, "\n\r");
+		return(ret);
+	}
+	return(NULL); /* To make gcc happy. */
+}
 
 
 /*
 void dact_ui_debug()
-void dact_ui_getuserinput()
 */
